pre {
  margin: 0;
  font-size: 0.8rem;
  white-space: pre-wrap;
  background-color: #23241f;
}

body {
  background-color: #252526;
  color: white;
}

.query {
  border: 1px solid white;
}

.modal-body {
  padding: 0;
}

.modal-title {
  color: black;
}

.modal-content {
  border-radius: 0;
  border: 1px solid white;
  width: 100%;
}

.modal-header {
  padding: 8px;
}

.section {
  height: 100%;
  display: flex;
  align-items: center;
  /* justify-content: center; */
  font-size: 0.7rem;
  padding: 0 0.5rem;
}

.top-bar {
  display: grid;
  align-items: center;
  justify-items: stretch;
  background-color: #252620;
  font-size: 0.8rem;
  height: 40px;
  border-bottom: 1px solid white;
}

.top-bar > * {
  border-right: 1px solid white;
}

.top-bar > div {
  height: 100%;
}

.button,
.button:hover {
  display: inline;
  border: none;
  color: white;
  font-size: 0.8rem;
  background-color: rgba(0, 0, 0, 0);
  text-decoration: none;
  text-align: center;
  vertical-align: middle;
}

.query-detail-bar {
  grid-template-columns: 30px 120px 120px 80px 80px 1fr 80px 80px 80px;
}

.query-list-bar {
  grid-template-columns: 30px 200px 150px 150px 1fr 80px 80px;
}

.modal-bar {
  grid-template-columns: 30px 1fr  80px;
}

.modal-traceback-bar {
  grid-template-columns: 30px 1fr 80px 80px;
}

.top-bar > button {
  border: none;
  border-right: 1px solid white;
  height: 100%;
  padding: 8px;
  color: white;
  font-size: 0.8rem;
  background-color: rgba(0, 0, 0, 0);
}

.counter {
  border-right: 1px solid white;
  font-size: 1rem;
  height: 100%;
}

.two-column {
  display: flex;
  flex-direction: row;
.top-bar > button {
  border: none;
  border-right: 1px solid white;
  height: 100%;
  padding: 8px;
  color: white;
  font-size: 0.8rem;
  background-color: rgba(0, 0, 0, 0);
}

.counter {
  border-right: 1px solid white;
  font-size: 1rem;
  height: 100%;
}

.two-column {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  align-items: center;
}
